@@ -1,6 +1,5 @@
 from time import sleep
 from typing import List, Dict, Callable
-import pandas as pd
 
 from ledgerx import DELAY_SECONDS
 from ledgerx.http_client import HttpClient
@@ -14,15 +13,21 @@ class GenericResource:
         return res.json()
 
     @classmethod
-    def list(cls, url: str, params: Dict):
-        res = HttpClient.get(url, params)
+    def list(cls, url: str, params: Dict, include_api_key: bool = False):
+        res = HttpClient.get(url, params, include_api_key)
         return res.json()
 
     @classmethod
-    def list_all(cls, url: str, params: Dict = {}, max_fetches: int = 0) -> List[Dict]:
+    def list_all(
+        cls,
+        url: str,
+        params: Dict = {},
+        include_api_key: bool = False,
+        max_fetches: int = 0,
+    ) -> List[Dict]:
         elements = []
 
-        json_data = cls.list(url, params)
+        json_data = cls.list(url, params, include_api_key)
         elements.extend(json_data["data"])
 
         while has_next_url(json_data):
@@ -36,10 +41,11 @@ class GenericResource:
         cls,
         url: str,
         params: Dict = {},
+        include_api_key: bool = False,
         callback: Callable = None,
         max_fetches: int = 0,
     ) -> None:
-        json_data = cls.list(url, params)
+        json_data = cls.list(url, params, include_api_key=include_api_key)
         callback(json_data["data"])
 
         while has_next_url(json_data):
